@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # This file is part of Invenio.
-# Copyright (C) 2016-2018 CERN.
+# Copyright (C) 2016-2022 CERN.
 # Copyright (C) 2021 Graz University of Technology.
 #
 # Invenio is free software; you can redistribute it and/or modify it
@@ -9,12 +9,13 @@
 
 """Persistent identifier fetchers."""
 
-from __future__ import absolute_import, print_function
-
+from elasticsearch_dsl.query import Q
 from invenio_pidstore.errors import PersistentIdentifierError
 from invenio_pidstore.fetchers import FetchedPID
 
+from .models import OAISet
 from .provider import OAIIDProvider
+from .query import query_string_parser
 
 
 def oaiid_fetcher(record_uuid, data):
@@ -24,7 +25,7 @@ def oaiid_fetcher(record_uuid, data):
     :param data: The record data.
     :returns: A :class:`invenio_pidstore.fetchers.FetchedPID` instance.
     """
-    pid_value = data.get('_oai', {}).get('id')
+    pid_value = data.get("_oai", {}).get("id")
     if pid_value is None:
         raise PersistentIdentifierError()
 
@@ -33,3 +34,15 @@ def oaiid_fetcher(record_uuid, data):
         pid_type=OAIIDProvider.pid_type,
         pid_value=str(pid_value),
     )
+
+
+def set_records_query_fetcher(setSpec):
+    """Fetch query to retrieve records based on provided set spec."""
+    set = OAISet.query.filter(OAISet.spec == setSpec).first()
+    if set is None:
+        # raise error that no matches can be found ?
+        query = Q("match_none")
+    else:
+        query = Q(query_string_parser(set.search_pattern))
+
+    return query
