@@ -1,19 +1,15 @@
 # -*- coding: utf-8 -*-
 #
 # This file is part of Invenio.
-# Copyright (C) 2016-2018 CERN.
+# Copyright (C) 2016-2022 CERN.
 #
 # Invenio is free software; you can redistribute it and/or modify it
 # under the terms of the MIT License; see LICENSE file for more details.
 
 """Helper proxy to the state object."""
 
-from __future__ import absolute_import, print_function
-
 from flask import current_app
 from werkzeug.local import LocalProxy
 
-current_oaiserver = LocalProxy(
-    lambda: current_app.extensions['invenio-oaiserver']
-)
+current_oaiserver = LocalProxy(lambda: current_app.extensions["invenio-oaiserver"])
 """Helper proxy to access state object."""
